==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/appmesh/kotlin/outputs/GetRouteSpecHttpRoute.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.appmesh.kotlin.outputs

import kotlin.Suppress
import kotlin.collections.List

/**
 *
 * @property actions
 * @property matches
 * @property retryPolicies
 * @property timeouts
 */
public data class GetRouteSpecHttpRoute(
    public val actions: List<GetRouteSpecHttpRouteAction>,
    public val matches: List<GetRouteSpecHttpRouteMatch>,
    public val retryPolicies: List<GetRouteSpecHttpRouteRetryPolicy>,
    public val timeouts: List<GetRouteSpecHttpRouteTimeout>,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.aws.appmesh.outputs.GetRouteSpecHttpRoute):
            GetRouteSpecHttpRoute = GetRouteSpecHttpRoute(
            actions = javaType.actions().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.appmesh.kotlin.outputs.GetRouteSpecHttpRouteAction.Companion.toKotlin(args0)
                })
            }),
            matches = javaType.matches().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.appmesh.kotlin.outputs.GetRouteSpecHttpRouteMatch.Companion.toKotlin(args0)
                })
            }),
            retryPolicies = javaType.retryPolicies().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.appmesh.kotlin.outputs.GetRouteSpecHttpRouteRetryPolicy.Companion.toKotlin(args0)
                })
            }),
            timeouts = javaType.timeouts().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.appmesh.kotlin.outputs.GetRouteSpecHttpRouteTimeout.Companion.toKotlin(args0)
                })
            }),
        )
    }
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/appmesh/kotlin/outputs/GetRouteSpecHttpRoute.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.appmesh.kotlin.outputs

import kotlin.Suppress
import kotlin.collections.List

/**
 *
 * @property actions
 * @property matches
 * @property retryPolicies
 * @property timeouts
 */
public data class GetRouteSpecHttpRoute(
    public val actions: List<GetRouteSpecHttpRouteAction>,
    public val matches: List<GetRouteSpecHttpRouteMatch>,
    public val retryPolicies: List<GetRouteSpecHttpRouteRetryPolicy>,
    public val timeouts: List<GetRouteSpecHttpRouteTimeout>,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.aws.appmesh.outputs.GetRouteSpecHttpRoute): GetRouteSpecHttpRoute = GetRouteSpecHttpRoute(
            actions = javaType.actions().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.appmesh.kotlin.outputs.GetRouteSpecHttpRouteAction.Companion.toKotlin(args0)
                })
            }),
            matches = javaType.matches().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.appmesh.kotlin.outputs.GetRouteSpecHttpRouteMatch.Companion.toKotlin(args0)
                })
            }),
            retryPolicies = javaType.retryPolicies().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.appmesh.kotlin.outputs.GetRouteSpecHttpRouteRetryPolicy.Companion.toKotlin(args0)
                })
            }),
            timeouts = javaType.timeouts().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.appmesh.kotlin.outputs.GetRouteSpecHttpRouteTimeout.Companion.toKotlin(args0)
                })
            }),
        )
    }
}
